@@ -371,7 +371,8 @@ setMethod(
   # For additional metadata:
   # Some numeric columns may be stored as character - convert these to numeric
   # Make a copy to preserve original columns.
-  cellColDataCopy <- data.frame(cellColData)
+  cellColDataCopy <- as.data.frame(dplyr::filter(data.frame(cellColData), 
+                                                 !!as.name(cellPopLabel) %in% cellPopulations))
   cellColDataCopy[] <- lapply(cellColDataCopy, function(x) {
     utils::type.convert(as.character(x), as.is = TRUE)
   })
@@ -399,7 +400,7 @@ setMethod(
             values_from = meanValues
           )
       )
-
+     
       summarizedData <- as.data.frame(summarizedData)
       rownames(summarizedData) <- summarizedData[[cellPopLabel]]
       summarizedData <- summarizedData[, -1, drop = FALSE]
@@ -518,13 +519,15 @@ setMethod(
       rm(covFiles)
     }
 
+    #parallel::stopCluster(cl)
+      
     # This pbapply will parallelize over each sample within a celltype.
     # Each arrow is a sample so this is allowed
     # (Arrow files are locked - one access at a time)
     iterList <- lapply(seq_along(frags), function(x) {
       list(blackList, frags[[x]], cellCol, verbose, study_prefactor)
     })
-    cl <- parallel::makeCluster(numCores)
+    #cl <- parallel::makeCluster(numCores)
     tilesGRangesList <- pbapply::pblapply(
       cl = cl,
       X = iterList,
@@ -593,17 +596,69 @@ setMethod(
   sampleData <- suppressWarnings(
     sampleDataFromCellColData(cellColData, sampleLabel = "Sample")
   )
-
-  summarizedData <- SummarizedExperiment::SummarizedExperiment(
-    append(
-      list(
-        "CellCounts" = allCellCounts,
-        "FragmentCounts" = allFragmentCounts
-      ),
-      additionalMetaData
+  
+  sumDataAssayList <- append(
+    list(
+      "CellCounts" = allCellCounts,
+      "FragmentCounts" = allFragmentCounts
     ),
+    additionalMetaData
+  )
+  
+  # Enforce Row and Column orders in sumDataAssayList and sampleData
+  colOrder <- colnames(allCellCounts)
+  rowOrder <- rownames(allCellCounts)
+  
+  for (i in seq_along(sumDataAssayList)) {
+    assayName <- names(sumDataAssayList[i])
+    assay <- sumDataAssayList[[i]]
+    sumDataAssayList[assayName] <- list(assay[rowOrder, colOrder])
+  }
+
+  sampleData <- dplyr::arrange(
+    sampleData, factor(Sample, levels = colOrder)
+  )
+  rownames(sampleData) <- sampleData[,"Sample"]
+  
+  # Validate Row and Column orders
+  if(verbose){
+    if(!all(rownames(sampleData) == colnames(allCellCounts))){
+      warning("SampleData and allCellCounts samples mismatch:",
+              "sampleData rownames:", rownames(sampleData),
+              "allCellCounts colnames:", rownames(allCellCounts))
+    }
+    if (length(unique(lapply(sumDataAssayList, dim)))>1){
+      warning("Assays in sumDataAssayList have different dimensions: ",
+              paste(unique(lapply(sumDataAssayList, dim)), collapse="\n"))
+    }
+    if (length(unique(lapply(sumDataAssayList, rownames)))>1){
+      warning("Assays in sumDataAssayList have different rownames: ",
+              paste(unique(lapply(sumDataAssayList, rownames)), collapse="\n"))
+    }
+    if (length(unique(lapply(sumDataAssayList, colnames)))>1){
+      warning("Assays in sumDataAssayList have different colnames: ",
+        paste(unique(lapply(sumDataAssayList, colnames)), collapse="\n"))
+    }
+  }
+  
+  summarizedData <- SummarizedExperiment::SummarizedExperiment(
+    sumDataAssayList,
     colData = sampleData
   )
+  
+  # Match cell populations in allCellCounts/allFragmentCounts to those
+  # in additionalMetaData, in case of NA cell populations
+  if(length(additionalMetaData) >= 1){
+    allCellCounts <- allCellCounts[
+      match(rownames(additionalMetaData[[1]]), rownames(allCellCounts))
+      , , drop=FALSE
+    ]
+    
+    allFragmentCounts <- allFragmentCounts[
+      match(rownames(additionalMetaData[[1]]), rownames(allFragmentCounts))
+      , , drop=FALSE
+    ]
+  }
 
   # Add experimentList to MultiAssayExperiment
   names(experimentList) <- cellPopulations
